MODULE zdf_oce
   !!======================================================================
   !!              ***  MODULE  zdf_oce  ***
   !! Ocean physics : define vertical mixing variables
   !!=====================================================================
   !! history :  1.0  !  2002-06  (G. Madec) Original code
   !!            3.2  !  2009-07  (G.Madec) addition of avm
   !!----------------------------------------------------------------------

   !!----------------------------------------------------------------------
   USE par_oce         ! ocean parameters

   IMPLICIT NONE
   PRIVATE

#if defined key_zdfcst   ||   defined key_esopa
   LOGICAL, PARAMETER, PUBLIC ::   lk_zdfcst        = .TRUE.         !: constant vertical mixing flag
#else
   LOGICAL, PARAMETER, PUBLIC ::   lk_zdfcst        = .FALSE.        !: constant vertical mixing flag
#endif

   !                                          !!* namelist namzdf: vertical diffusion
   LOGICAL , PUBLIC ::   ln_zdfexp = .FALSE.   !: explicit vertical diffusion scheme flag
   LOGICAL , PUBLIC ::   ln_zdfevd = .TRUE.    !: convection: enhanced vertical diffusion flag
   LOGICAL , PUBLIC ::   ln_zdfnpc = .FALSE.   !: convection: non-penetrative convection flag
   INTEGER , PUBLIC ::   n_zdfexp = 3          !: number of sub-time step (explicit time stepping)
   INTEGER , PUBLIC ::   n_evdm   = 1          !: =0/1 flag to apply enhanced avm or not
   REAL(wp), PUBLIC ::   avm0  = 1.e-4_wp      !: vertical eddy viscosity (m2/s)
   REAL(wp), PUBLIC ::   avt0  = 1.e-5_wp      !: vertical eddy diffusivity (m2/s)
   REAL(wp), PUBLIC ::   avevd = 1._wp         !: vertical eddy coeff. for enhanced vert. diff. (m2/s)

   REAL(wp), PUBLIC, DIMENSION        (jpk) ::   avmb, avtb   !: background profile of avm and avt
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   avmu, avmv   !: vertical viscosity coeff. at uw- & vw-points   [m2/s]
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   avm , avt    !: vertical viscosity & diffusivity coeff. at  w-point   [m2/s]
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   avt_evd      !: enhanced vertical diffusivity coeff. at  w-point   [m2/s]
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   avmu_evd     !: enhanced vertical viscosity   coeff. at uw-point   [m2/s]
#if defined key_zdftmx
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   av_tide      !: Tidal mixing
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   av_tide_itf  !: Tidal mixing in the Indonesian Through Flow
#endif
 
   !!----------------------------------------------------------------------
   !! NEMO/OPA 3.2 , LOCEAN-IPSL (2009) 
   !! $Id$ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!======================================================================
END MODULE zdf_oce
